@@ -31,6 +31,8 @@ def push(file):
             config_json = ast.literal_eval(str)
             checkToolConfig(config_json)
         pushImage(config_json)
+    print("push successful")
+
 
 def pushImage(config_json):
     if config_json['id'] == '':
@@ -108,8 +110,6 @@ def checkToolConfig(toolConfig):
     if toolConfig['cmd'] != '':
         toolVersionCmdParamList = analysis(cmd=toolConfig['cmd'])
 
-    print("===========================toolVersionCmdParamList===========================")
-    print(toolVersionCmdParamList)
     toolInputFileList = toolConfig['inputs']
 
     inLabelSet = set()
